==> acomea.contact-0.1.tar.gz: acomea.contact-0.1/acomea/contact/settings.py <==
# -*- coding: utf-8 -*-
from django.utils.translation import ugettext_lazy as _

CONTACT_ADDRESS_TYPE_CHOICES = (
        ('corso', _(u'Corso')),
        ('largo', _(u'Largo')),
        ('localita', _(u'Località')),
        ('piazza', _(u'Piazza')),
        ('strada', _(u'Strada/Stretto')),
        ('traversa', _(u'Traversa')),
        ('via', _(u'Via')),
        ('viale', _(u'Viale')),
        ('vicolo', _(u'Vicolo/Vico')),
        ('circonvallazione', _(u'Circonvallazione')),
        ('frazione', _(u'Frazione')),
        ('rione', _(u'Rione')),
        ('salita', _(u'Salita')),
        ('contrada', _(u'Contrada')),
        ('statale', _(u'Statale')),
        ('autostrada', _(u'Autostrada')),
        ('cascina', _(u'Cascina')),
        ('parco', _(u'Parco')),
        ('spalto', _(u'Spalto')),
        ('tangenziale', _(u'Tangenziale')),
        ('zona industriale', _(u'Zona industriale')),
        ('borgo', _(u'Borgo')),
        ('galleria', _(u'Galleria')),
        ('piazzale', _(u'Piazzale')),
        ('corte', _(u'Corte')),
        ('centro', _(u'Centro')),
        ('foro', _(u'Foro')),
        ('lungo', _(u'Lungo/Lungomare')),
        ('calle', _(u'Calle')),
        ('riviera', _(u'Riviera')),
        ('villaggio', _(u'Villaggio')),
        ('passaggio', _(u'Passaggio')),
        ('borgata', _(u'Borgata')),
        ('lungolago', _(u'Lungolago')),
    )

CONTACT_UTILS_COLUMNS = (
    'title_id', 'first_name', 'last_name', 'birth_date', 'ssn', 'organization',
    'group_id', 'role_id', 'url', 'source', 'category_id', 'interest_id', 'product_id', 'network_id',
    'date_subscription', 'date_unsubscription', 'is_test_contact',
    'default_email', 'email1', 'email2',
    'mobile', 'home_phone', 'work_phone',
    # address values
    'address_scope_id', 'address_type', 'name', 'number', 'zip_code',
    'locality', 'province', 'region', 'country_id',

    'note'
    )
CONTACT_UTILS_REQUIRED_COLUMNS = ('first_name', 'last_name', 'group_id',)

CONTACT_UTILS_GET_CONTACT_FIELD = ('first_name', 'last_name',)

CONTACT_UTILS_CONTACT_FIELDS = (
    'first_name', 'last_name', 'birth_date', 'ssn', 'organization',
    'url', 'source', 'date_subscription', 'date_unsubscription',
    'is_test_contact', 'note'
    )
#FOREIGNKEY_FIELDS = (
#    (Title, 'title_id', 'title'),
#    (Role, 'role_id', 'role'),
#    (Category, 'category_id', 'category'),
#    (Network, 'network_id', 'network'),
#    )
#MANY_TO_MANY_FIELDS = (
#    (Group, 'group_id', 'groups'),
#    (Interest, 'interest_id', 'interests'),
#    (Product, 'product_id', 'products'),
#    )
CONTACT_UTILS_EMAIL_FIELDS = (
    'default_email', 'email1', 'email2',
    )
CONTACT_UTILS_GET_ADDRESS_FIELDS = (
    'name', 'locality',
    )
CONTACT_UTILS_ADDRESS_FIELDS = (
    'address_type', 'name', 'number', 'zip_code',
    'locality', 'province', 'region', 'country_id'
    )
CONTACT_UTILS_MANY_TO_MANY_ADDRESS = (
    'address_scope_id',
    )
CONTACT_UTILS_PHONE_FIELDS = (
    ('mobile', 1),
    ('home_phone', 2),
    ('work_phone', 2),
    )

CONTACT_CMSPLUGINS_TRACEREQUESTS_FORM_TEMPLATES = (
    ("contact/cms_plugins/trace_request_form.html", _("trace requests form template"),),
    ("contact/cms_plugins/trace_request_form_nomodal.html", _("trace requests form template (no modal)"),),
    ("contact/cms_plugins/contact_form3_nomodal.html", _("contact form 3 (no modal)"),),
)

CONTACT_CMSPLUGINS_TRACEREQUESTS_DONE_TEMPLATES = (
    ("contact/cms_plugins/trace_request_done.html", _("trace requests done template"),),
)

# CONTACT_FORM_CMSPLUGIN_EMAIL_TEMPLATES = (
#     ("cms_plugins/contact_email.html", _("contact email sent template"),),
# )

CONTACT_CMSPLUGINS_TRACEREQUESTS_FORM_CLASSES = (
    ("acomea.contact.forms.TraceRequestsForm", _("trace requests form"),),
    ("acomea.contact.forms.ExtendedTraceRequestsForm", _("trace requests form w/ privacy fields"),),
)

CONTACT_CMSPLUGINS_TRACEREQUESTS_FORM_SUBMIT_ALIGNMENT_CHOICES = (
    ('center', "Center"),
    ('left', "Left"),
    ('right', "Right"),
)

# scelte autorizzazioni (portate da 'profilo')
AUTH_CHOICES = (
    (True, 'Accetto',),
    (False, 'Non Accetto',),
)

# labels campi auth
URL_PAGINA_INFORMATIVA = "https://www.acomea.it/it/registrazione/informativa/"

AUTH_TRATTAMENTO_DATI_LABEL = u'Dichiaro di aver attentamente letto <a href="%s" class="informativa-url">l’informativa</a> ' \
                              u'e sono consapevole che il trattamento dei dati è necessario per ottenere i ' \
                              u'servizi proposti dal sito' % URL_PAGINA_INFORMATIVA
AUTH_MATERIALE_COMMERCIALE_LABEL = u'Autorizzo il trattamento dei miei dati personali da parte di AcomeA per fini di ' \
                                   u'informazione commerciale ed offerte dirette di prodotti/servizi'
AUTH_SOCIETA_TERZE_LABEL = u'Autorizzo il trattamento e la comunicazione dei miei dati personali da parte di AcomeA ' \
                           u'a società terze, previa comunicazione da parte di AcomeA, per fini di informazione ' \
                           u'commerciale ed offerte dirette di prodotti/servizi di società terze.'
AUTH_TRATTAMENTO_DATI_ERR_MSG = u"E' necessario accettare l'autorizzazione al trattamento dati."
AUTH_MATERIALE_COMMERCIALE_ERR_MSG = u"E' necessario accettare l'autorizzazione all'invio di materiale commerciale."


# gestione privacy
CONTACT_CMSPLUGINS_PRIVACYMANAGEMENT_FORM_TEMPLATES = (
    ("contact/cms_plugins/privacy_management_form.html", _("Privacy management form template"),),
)
CONTACT_CMSPLUGINS_PRIVACYMANAGEMENT_FORM_CLASSES = (
    ("acomea.contact.forms.PrivacyManagementForm", _("Privacy management form"),),
)

# nome gruppo 'Investitori Professionali'
CONTACT_GROUP_INVESTITORI_PROFESSIONALI = "Investitori Professionali"
CONTACT_GROUP_NEWSLETTER_PRIVATI = "Newsletter privati"

# email conferma contatto
CONTACT_CONFIRM_EMAIL_TEMPLATE = "contact/contact_confirm_email.html"
CONTACT_CONFIRM_LANDINGPAGE_RELATIVE_URL = "/registrazione/conferma-contatto"
CONTACT_CONFIRM_EMAIL_SENT_FROM = "info@acomea.it"
CONTACT_CONFIRM_TIMEOUT_DAYS = 3

# template pagina atterraggio successo conferma contatto
CONTACT_CMSPLUGINS_CONFIRMCONTACT_DONE_TEMPLATES = (
    ("contact/cms_plugins/contact_confirm_done.html", _("Contact confirm done template"),),
)

# override following setting in local.py for sending confirm email to that address
#CONTACT_CONFIRM_EMAIL_SENT_TO = ""
CONTACT_CMSAPPS_CONFIRMPRIVACYFORM_TEMPLATE = "contact/cms_apps/confirm_privacy_form.html"
CONTACT_CMSAPPS_CONFIRMPRIVACY_HAS_RELATED_USER_TEMPLATE = "contact/cms_apps/confirm_privacy_has_related_user.html"
CONTACT_CMSAPPS_CONFIRMPRIVACY_CONFIRM_PRIVACYDATA_SEND_TO = "registrazione@acomea.it"
CONTACT_CMSAPPS_CONFIRMPRIVACY_CONFIRMDATA_TEMPLATE = "contact/cms_apps/confirm_privacydata.html"
CONTACT_CMSAPPS_CONFIRMPRIVACY_CONTACT_DELETE_TO_BACKOFFICE_EMAIL_TEMPLATE = "contact/cms_apps/confirm_contact_delete_to_backoffice_email.html"
CONTACT_CMSAPPS_CONFIRMPRIVACY_CANCEL_CONTACT_TEMPLATE = "contact/cms_apps/confirm_cancel_contact.html"
CONTACT_CMSAPPS_CONFIRMPRIVACY_EMAIL_TEMPLATE = "contact/cms_apps/confirm_privacydata_email.html"
CONTACT_CMSAPPS_CONFIRMPRIVACY_CONTACT_DELETE_TO_BACKOFFICE_EMAIL_SENT_TO = "privacy@acomea.it"

# email traccia richieste
CONTACT_TRACEREQUESTS_EMAIL_TEMPLATE = "contact/trace_requests_email.html"

==> acomea.contact-0.2.tar.gz: acomea.contact-0.2/acomea/contact/settings.py <==
# -*- coding: utf-8 -*-
from django.utils.translation import ugettext_lazy as _

CONTACT_ADDRESS_TYPE_CHOICES = (
        ('corso', _(u'Corso')),
        ('largo', _(u'Largo')),
        ('localita', _(u'Località')),
        ('piazza', _(u'Piazza')),
        ('strada', _(u'Strada/Stretto')),
        ('traversa', _(u'Traversa')),
        ('via', _(u'Via')),
        ('viale', _(u'Viale')),
        ('vicolo', _(u'Vicolo/Vico')),
        ('circonvallazione', _(u'Circonvallazione')),
        ('frazione', _(u'Frazione')),
        ('rione', _(u'Rione')),
        ('salita', _(u'Salita')),
        ('contrada', _(u'Contrada')),
        ('statale', _(u'Statale')),
        ('autostrada', _(u'Autostrada')),
        ('cascina', _(u'Cascina')),
        ('parco', _(u'Parco')),
        ('spalto', _(u'Spalto')),
        ('tangenziale', _(u'Tangenziale')),
        ('zona industriale', _(u'Zona industriale')),
        ('borgo', _(u'Borgo')),
        ('galleria', _(u'Galleria')),
        ('piazzale', _(u'Piazzale')),
        ('corte', _(u'Corte')),
        ('centro', _(u'Centro')),
        ('foro', _(u'Foro')),
        ('lungo', _(u'Lungo/Lungomare')),
        ('calle', _(u'Calle')),
        ('riviera', _(u'Riviera')),
        ('villaggio', _(u'Villaggio')),
        ('passaggio', _(u'Passaggio')),
        ('borgata', _(u'Borgata')),
        ('lungolago', _(u'Lungolago')),
    )

CONTACT_UTILS_COLUMNS = (
    'title_id', 'first_name', 'last_name', 'birth_date', 'ssn', 'organization',
    'group_id', 'role_id', 'url', 'source', 'category_id', 'interest_id', 'product_id', 'network_id',
    'date_subscription', 'is_test_contact',
    'default_email', 'email1', 'email2',
    'mobile', 'home_phone', 'work_phone',
    # address values
    'address_scope_id', 'address_type', 'name', 'number', 'zip_code',
    'locality', 'province', 'region', 'country_id',

    'note'
    )
CONTACT_UTILS_REQUIRED_COLUMNS = ('first_name', 'last_name', 'group_id',)

CONTACT_UTILS_GET_CONTACT_FIELD = ('first_name', 'last_name',)

CONTACT_UTILS_CONTACT_FIELDS = (
    'first_name', 'last_name', 'birth_date', 'ssn', 'organization',
    'url', 'source', 'date_subscription', 'is_test_contact', 'note'
)
#FOREIGNKEY_FIELDS = (
#    (Title, 'title_id', 'title'),
#    (Role, 'role_id', 'role'),
#    (Category, 'category_id', 'category'),
#    (Network, 'network_id', 'network'),
#    )
#MANY_TO_MANY_FIELDS = (
#    (Group, 'group_id', 'groups'),
#    (Interest, 'interest_id', 'interests'),
#    (Product, 'product_id', 'products'),
#    )
CONTACT_UTILS_EMAIL_FIELDS = (
    'default_email', 'email1', 'email2',
    )
CONTACT_UTILS_GET_ADDRESS_FIELDS = (
    'name', 'locality',
    )
CONTACT_UTILS_ADDRESS_FIELDS = (
    'address_type', 'name', 'number', 'zip_code',
    'locality', 'province', 'region', 'country_id'
    )
CONTACT_UTILS_MANY_TO_MANY_ADDRESS = (
    'address_scope_id',
    )
CONTACT_UTILS_PHONE_FIELDS = (
    ('mobile', 1),
    ('home_phone', 2),
    ('work_phone', 2),
    )

CONTACT_CMSPLUGINS_DEFAULT_TRACEREQUESTS_FORM_TEMPLATES = (
    ("contact/cms_plugins/trace_request_form.html", _("trace requests form template"),),
    ("contact/cms_plugins/trace_request_form_nomodal.html", _("trace requests form template (no modal)"),),
    ("contact/cms_plugins/contact_form3_nomodal.html", _("contact form 3 (no modal)"),),
    ("bootstrap3/contact/cms_plugins/contact_form.html", _("B3 - contact form"),),
)

CONTACT_CMSPLUGINS_PRESET_TRACEREQUESTS_FORM_TEMPLATES = (
    ("contact/cms_plugins/preset_trace_request_form.html", _("preset trace requests form template"),),
    ("contact/cms_plugins/preset_trace_request_form_nomodal.html", _("preset trace requests form template (no modal)"),),
    ("contact/cms_plugins/preset_contact_form3_nomodal.html", _("preset contact form 3 (no modal)"),),
    ("contact/cms_plugins/preset_contact_form3_nomodal_inline_msgs.html", _("preset contact form 3 inline messages (no modal)"),),
    ("bootstrap3/contact/cms_plugins/preset_contact_form.html", _("B3 - preset contact form"),),
    ("bootstrap3/contact/cms_plugins/preset_embedded_contact_form.html", _("B3 - preset embedded contact form"),),
)

CONTACT_CMSPLUGINS_TRACEREQUESTS_FORM_TEMPLATES = CONTACT_CMSPLUGINS_DEFAULT_TRACEREQUESTS_FORM_TEMPLATES + \
    CONTACT_CMSPLUGINS_PRESET_TRACEREQUESTS_FORM_TEMPLATES

CONTACT_CMSPLUGINS_TRACEREQUESTS_DONE_TEMPLATES = (
    ("contact/cms_plugins/trace_request_done.html", _("trace requests done template"),),
)

# CONTACT_FORM_CMSPLUGIN_EMAIL_TEMPLATES = (
#     ("cms_plugins/contact_email.html", _("contact email sent template"),),
# )

CONTACT_CMSPLUGINS_DEFAULT_TRACEREQUESTS_FORM_CLASSES = (
    ("acomea.contact.forms.TraceRequestsForm", _("trace requests form"),),
    ("acomea.contact.forms.ExtendedTraceRequestsForm", _("trace requests form w/ privacy fields"),),
)

CONTACT_CMSPLUGINS_PRESET_TRACEREQUESTS_FORM_CLASSES = (
    ("acomea.contact.forms.PresetTraceRequestsForm", _("preset trace requests form"),),
    ("acomea.contact.forms.PresetExtendedTraceRequestsForm", _("preset trace requests form w/ privacy fields"),),
)


CONTACT_CMSPLUGINS_TRACEREQUESTS_FORM_CLASSES = CONTACT_CMSPLUGINS_DEFAULT_TRACEREQUESTS_FORM_CLASSES + \
    CONTACT_CMSPLUGINS_PRESET_TRACEREQUESTS_FORM_CLASSES


CONTACT_CMSPLUGINS_TRACEREQUESTS_FORM_SUBMIT_ALIGNMENT_CHOICES = (
    ('center', "Center"),
    ('left', "Left"),
    ('right', "Right"),
)

# scelte autorizzazioni (portate da 'profilo')
AUTH_CHOICES = (
    (True, 'Accetto',),
    (False, 'Non Accetto',),
)

# labels campi auth
URL_PAGINA_INFORMATIVA = "https://www.acomea.it/it/registrazione/informativa/"

AUTH_TRATTAMENTO_DATI_LABEL = u'Dichiaro di aver attentamente letto <a href="%s" class="informativa-url">l’informativa</a> ' \
                              u'e sono consapevole che il trattamento dei dati è necessario per ottenere i ' \
                              u'servizi proposti dal sito' % URL_PAGINA_INFORMATIVA
AUTH_MATERIALE_COMMERCIALE_LABEL = u'Autorizzo il trattamento dei miei dati personali da parte di AcomeA per fini di ' \
                                   u'informazione commerciale ed offerte dirette di prodotti/servizi'
AUTH_SOCIETA_TERZE_LABEL = u'Autorizzo il trattamento e la comunicazione dei miei dati personali da parte di AcomeA ' \
                           u'a società terze, previa comunicazione da parte di AcomeA, per fini di informazione ' \
                           u'commerciale ed offerte dirette di prodotti/servizi di società terze.'
AUTH_TRATTAMENTO_DATI_ERR_MSG = u"E' necessario accettare l'autorizzazione al trattamento dati."
AUTH_MATERIALE_COMMERCIALE_ERR_MSG = u"Informativa resa ai sensi del D.lgs. 196/03: Questo campo è obbligatorio"
AUTH_SOCIETA_TERZE_ERR_MSG = u"E' necessario accettare l'autorizzazione al trattamento dati e la comunicazione dei "\
                             u"dati personali da parte di AcomeA a società terze."


# gestione privacy
CONTACT_CMSPLUGINS_PRIVACYMANAGEMENT_FORM_TEMPLATES = (
    ("contact/cms_plugins/privacy_management_form.html", _("Privacy management form template"),),
    ("bootstrap3/contact/cms_plugins/privacy_management_form.html", _("B3 - Privacy management form template"),),
    ("bootstrap3/contact/cms_plugins/auth_management_form.html", _("B3 - Auth management form template"),),
)
CONTACT_CMSPLUGINS_PRIVACYMANAGEMENT_FORM_CLASSES = (
    ("acomea.contact.forms.PrivacyManagementForm", _("Privacy management form"),),
    ("acomea.contact.forms.AuthPrivacyManagementForm", _("Auth management form"),),
)

# nome gruppo 'Investitori Professionali'
CONTACT_GROUP_INVESTITORI_PROFESSIONALI = "Investitori Professionali"
CONTACT_GROUP_NEWSLETTER_PRIVATI = "Newsletter privati"

# email conferma contatto
CONTACT_CONFIRM_EMAIL_TEMPLATE = "contact/contact_confirm_email.html"
CONTACT_CONFIRM_LANDINGPAGE_RELATIVE_URL = "/registrazione/conferma-contatto"
CONTACT_CONFIRM_EMAIL_SENT_FROM = "info@acomea.it"
CONTACT_CONFIRM_TIMEOUT_DAYS = 3

# template pagina atterraggio successo conferma contatto
CONTACT_CMSPLUGINS_CONFIRMCONTACT_DONE_TEMPLATES = (
    ("contact/cms_plugins/contact_confirm_done.html", _("Contact confirm done template"),),
)

# override following setting in local.py for sending confirm email to that address
#CONTACT_CONFIRM_EMAIL_SENT_TO = ""
CONTACT_CMSAPPS_CONFIRMPRIVACYFORM_TEMPLATE = "contact/cms_apps/confirm_privacy_form.html"
CONTACT_CMSAPPS_CONFIRMPRIVACY_HAS_RELATED_USER_TEMPLATE = "contact/cms_apps/confirm_privacy_has_related_user.html"
CONTACT_CMSAPPS_CONFIRMPRIVACY_CONFIRM_PRIVACYDATA_SEND_TO = "supporto@acomea.it"
CONTACT_CMSAPPS_CONFIRMPRIVACY_CONFIRMDATA_TEMPLATE = "contact/cms_apps/confirm_privacydata.html"
CONTACT_CMSAPPS_CONFIRMPRIVACY_CONTACT_DELETE_TO_BACKOFFICE_EMAIL_TEMPLATE = "contact/cms_apps/confirm_contact_delete_to_backoffice_email.html"
CONTACT_CMSAPPS_CONFIRMPRIVACY_CANCEL_CONTACT_TEMPLATE = "contact/cms_apps/confirm_cancel_contact.html"
CONTACT_CMSAPPS_CONFIRMPRIVACY_EMAIL_TEMPLATE = "contact/cms_apps/confirm_privacydata_email.html"
CONTACT_CMSAPPS_CONFIRMPRIVACY_CONTACT_DELETE_TO_BACKOFFICE_EMAIL_SENT_TO = "privacy@acomea.it"

# email traccia richieste
CONTACT_TRACEREQUESTS_EMAIL_TEMPLATE = "contact/trace_requests_email.html"

# Gruppi id default ai quali il contato viene assegnato in fase di creazione
ACOMEA_CONTACT_BASE_GROUPS = [1, 8]
CONTACT_GROUP_FINE_PRIMA_SOTTOSCRIZIONE_GROUP_ID = 951

CHECK_CONTACT_GROUP_REPORT_MAIL_LIST = [
    'jumbo@thux.it'
]
